@@ -1,5 +1,5 @@
 class PlanetInput:
-    def __init__(self, P, a, r, e, omega=0.0):
+    def __init__(self, P, r, e, a=0.1, omega=0.0):
         self.P = P
         self.a = a
         self.r = r
