@@ -4,15 +4,16 @@ class MissionFfiIdObjectInfo(ObjectInfo):
     """
     Implementation of ObjectInfo to be used to characterize long-cadence objects.
     """
-    def __init__(self, mission_id, sectors, initial_mask=None, initial_detrend_period=None):
+    def __init__(self, mission_id, sectors, initial_mask=None, initial_detrend_period=None, star_info=None):
         """
         @param mission_id: the mission identifier. TIC ##### for TESS, KIC ##### for Kepler and EPIC ##### for K2.
         @param sectors: an array of integers specifying which sectors will be analysed for the object
         @param initial_mask: an array of time ranges provided to mask them into the initial object light curve.
         @param initial_detrend_period: integer value specifying a fixed value for an initial period to be detrended
+        @param star_info: input star information
         from the initial light curve before processing.
         """
-        super().__init__(initial_mask, initial_detrend_period)
+        super().__init__(initial_mask, initial_detrend_period, star_info)
         self.id = mission_id
         self.sectors = sectors
 
