@@ -165,7 +165,7 @@ class Sherlock:
                                     search_zone=None, user_search_zone=None, period_min=0.5, period_max=20,
                                     bin_minutes=10, run_cores=NUM_CORES, snr_min=5, sde_min=5, fap_max=0.1,
                                     mask_mode="mask", best_signal_algorithm='border-correct', quorum_strength=1,
-                                    min_quorum=0, user_selection_algorithm=None, fit_method="default",
+                                    min_quorum=0, user_selection_algorithm=None, fit_method="tls",
                                     oversampling=None, t0_fit_margin=0.05, duration_grid_step=1.1):
         """
         Configures the values to be used for the transit fitting and the main run loop.
@@ -225,8 +225,14 @@ class Sherlock:
                                        "user": user_selection_algorithm}
         self.best_signal_algorithm = best_signal_algorithm if user_selection_algorithm is None else "user"
         self.user_selection_algorithm = user_selection_algorithm
-        self.fit_method = fit_method
+        self.fit_method = "default"
+        if fit_method is not None and fit_method.lower() == 'bls':
+            self.fit_method = "box"
+        elif fit_method is not None and fit_method.lower() == 'grazing':
+            self.fit_method = "grazing"
         self.oversampling = oversampling
+        if self.oversampling is not None:
+            self.oversampling = int(self.oversampling)
         self.t0_fit_margin = t0_fit_margin
         self.duration_grid_step = duration_grid_step
         return self
@@ -525,6 +531,9 @@ class Sherlock:
             logging.info('radius = %.6f', star_info.radius)
             logging.info('radius_min = %.6f', star_info.radius_min)
             logging.info('radius_max = %.6f', star_info.radius_max)
+            logging.info('teff = %.6f', star_info.teff)
+            logging.info('lum = %.6f', star_info.lum)
+            logging.info('logg = %.6f', star_info.logg)
         if not star_info.radius_assumed and not star_info.mass_assumed and star_info.teff is not None:
             star_df = pandas.DataFrame(columns=['ra', 'dec', 'R_star', 'R_star_lerr', 'R_star_uerr', 'M_star',
                                                 'M_star_lerr', 'M_star_uerr', 'Teff_star', 'Teff_star_lerr',
@@ -585,7 +594,7 @@ class Sherlock:
             logging.info('T0 Fit Margin: %.3f', self.t0_fit_margin)
         logging.info('Signal scoring algorithm: %s', self.best_signal_algorithm)
         if self.best_signal_algorithm == self.VALID_SIGNAL_SELECTORS[2]:
-            logging.info('Quorum algorithm vote strength: %.0f',
+            logging.info('Quorum algorithm vote strength: %.2f',
                          self.signal_score_selectors[self.VALID_SIGNAL_SELECTORS[2]].strength)
         if sectors is not None:
             sectors_count = len(sectors)
